@@ -285,14 +285,14 @@ std::ostream &operator<<(std::ostream &o, MWAWGraphicShape const &sh)
     break;
   case MWAWGraphicShape::Polygon:
     o << "polygons,pts=[";
-    for (size_t pt=0; pt < sh.m_vertices.size(); ++pt)
-      o << sh.m_vertices[pt] << ",";
+    for (auto const &pt : sh.m_vertices)
+      o << pt << ",";
     o << "],";
     break;
   case MWAWGraphicShape::Path:
     o << "path,pts=[";
-    for (size_t pt=0; pt < sh.m_path.size(); ++pt)
-      o << sh.m_path[pt] << ",";
+    for (auto const &pt : sh.m_path)
+      o << pt << ",";
     o << "],";
     break;
   case MWAWGraphicShape::ShapeUnknown:
@@ -354,10 +354,10 @@ void MWAWGraphicShape::translate(MWAWVec2f const &decal)
     return;
   m_bdBox=MWAWBox2f(m_bdBox.min()+decal, m_bdBox.max()+decal);
   m_formBox=MWAWBox2f(m_formBox.min()+decal, m_formBox.max()+decal);
-  for (size_t pt=0; pt<m_vertices.size(); ++pt)
-    m_vertices[pt]+=decal;
-  for (size_t pt=0; pt<m_path.size(); ++pt)
-    m_path[pt].translate(decal);
+  for (auto &pt : m_vertices)
+    pt+=decal;
+  for (auto &pt : m_path)
+    pt.translate(decal);
 }
 
 void MWAWGraphicShape::scale(MWAWVec2f const &scaling)
@@ -367,11 +367,10 @@ void MWAWGraphicShape::scale(MWAWVec2f const &scaling)
                     MWAWVec2f(scaling[0]*m_bdBox.max()[0],scaling[1]*m_bdBox.max()[1]));
   m_formBox=MWAWBox2f(MWAWVec2f(scaling[0]*m_formBox.min()[0],scaling[1]*m_formBox.min()[1]),
                       MWAWVec2f(scaling[0]*m_formBox.max()[0],scaling[1]*m_formBox.max()[1]));
-  for (size_t pt=0; pt<m_vertices.size(); ++pt)
-    m_vertices[pt]=MWAWVec2f(scaling[0]*m_vertices[pt][0],
-                             scaling[1]*m_vertices[pt][1]);
-  for (size_t pt=0; pt<m_path.size(); ++pt)
-    m_path[pt].scale(scaling);
+  for (auto &pt : m_vertices)
+    pt=MWAWVec2f(scaling[0]*pt[0], scaling[1]*pt[1]);
+  for (auto &pt : m_path)
+    pt.scale(scaling);
 }
 
 MWAWGraphicShape MWAWGraphicShape::rotate(float angle, MWAWVec2f const &center) const
@@ -392,8 +391,8 @@ MWAWGraphicShape MWAWGraphicShape::rotate(float angle, MWAWVec2f const &center)
   }
   MWAWGraphicShape res = path(fBox);
   res.m_path=getPath(false);
-  for (size_t p=0; p < res.m_path.size(); p++)
-    res.m_path[p].rotate(angle, decal);
+  for (auto &pt : res.m_path)
+    pt.rotate(angle, decal);
   return res;
 }
 
@@ -422,8 +421,8 @@ MWAWGraphicShape MWAWGraphicShape::transform(MWAWTransformation const &matrix) c
   MWAWVec2f shearing;
   if (!matrix.decompose(rotation,shearing,transf,fBox.center()))
     rotation=0;
-  for (size_t p=0; p < res.m_path.size(); p++)
-    res.m_path[p].transform(matrix, rotation);
+  for (auto &pt : res.m_path)
+    pt.transform(matrix, rotation);
   return res;
 }
 
@@ -437,9 +436,9 @@ bool MWAWGraphicShape::addPathTo(MWAWVec2f const &orig, librevenge::RVNGProperty
     return false;
   }
   librevenge::RVNGPropertyList list;
-  for (size_t c=0; c < n; ++c) {
+  for (auto const &pt : fPath) {
     list.clear();
-    if (fPath[c].get(list, -1.0f*decal))
+    if (pt.get(list, -1.0f*decal))
       vect.append(list);
   }
   if (fPath[n-1].m_type != 'Z') {
@@ -552,11 +551,11 @@ MWAWGraphicShape::Command MWAWGraphicShape::addTo(MWAWVec2f const &orig, bool as
   case Polygon: {
     size_t n=m_vertices.size();
     if (n<2) break;
-    for (size_t i = 0; i < n; ++i) {
+    for (auto point : m_vertices) {
       list.clear();
-      pt=m_vertices[i]+decal;
-      list.insert("svg:x", double(pt.x()), librevenge::RVNG_POINT);
-      list.insert("svg:y", double(pt.y()), librevenge::RVNG_POINT);
+      point += decal;
+      list.insert("svg:x", double(point.x()), librevenge::RVNG_POINT);
+      list.insert("svg:y", double(point.y()), librevenge::RVNG_POINT);
       vect.append(list);
     }
     propList.insert("svg:points", vect);
@@ -565,9 +564,9 @@ MWAWGraphicShape::Command MWAWGraphicShape::addTo(MWAWVec2f const &orig, bool as
   case Path: {
     size_t n=m_path.size();
     if (!n) break;
-    for (size_t c=0; c < n; ++c) {
+    for (auto const &point : m_path) {
       list.clear();
-      if (m_path[c].get(list, -1.0f*decal))
+      if (point.get(list, -1.0f*decal))
         vect.append(list);
     }
     if (asSurface && m_path[n-1].m_type != 'Z') {
@@ -596,7 +595,7 @@ std::vector<MWAWGraphicShape::PathData> MWAWGraphicShape::getPath(bool forTransf
   switch (m_type) {
   case Measure:
     MWAW_DEBUG_MSG(("MWAWGraphicShape::getPath: called on a measure, transform it in line\n"));
-  // fall through expected
+    MWAW_FALLTHROUGH;
   case Line:
   case Polygon: {
     size_t n=m_vertices.size();
@@ -671,6 +670,7 @@ std::vector<MWAWGraphicShape::PathData> MWAWGraphicShape::getPath(bool forTransf
       res.push_back(PathData('C',pt1, pt0+MWAWVec2f(0,dir[1]), pt1+MWAWVec2f(dir[0],0)));
       pt0=MWAWVec2f(m_formBox[0][0],center[1]);
       res.push_back(PathData('C',pt0, pt1-MWAWVec2f(dir[0],0), pt0+MWAWVec2f(0,dir[1])));
+      res.push_back(PathData('Z'));
     }
     else {
       MWAWVec2f pt0 = MWAWVec2f(m_formBox[0][0],0.5f*(m_formBox[0][1]+m_formBox[1][1]));
@@ -733,6 +733,7 @@ std::vector<MWAWGraphicShape::PathData> MWAWGraphicShape::getPath(bool forTransf
         pt=newPt;
         angl=newAngl;
       }
+      if (m_type==Pie) res.push_back(PathData('Z'));
     }
     break;
   }
